//ajax krempel hier hin pasten von main.js

function viewLetzteAuktion(los_nr){
	try{
		var markup = '<p>' + charge_data[(Number(los_nr) - 1)]['beschreibung'] + '</p>' +
		'<p>verkauft für: ' + charge_data[(Number(los_nr) - 1)]['vkPreis'] + '</p>';
		
		$('#letzteAuktion').html(markup);			
	}
	catch(e){
		$('#letzteAuktion').html('<p>keine Auktion beendet</p>');			
	}
};

function viewNaechsteAuktion(los_nr){
	try{
		var markup = '<p>' + charge_data[(Number(los_nr) + 1)]['beschreibung'] + '</p>' +
		'<p>Startpreis: ' + charge_data[(Number(los_nr) + 1)]['startPreis'] + '</p>';
	
		$('#naechsteAuktion').html(markup);
	}
	catch(e){
		$('#naechsteAuktion').html('<p>letzte Auktion läuft bereits!</p>');			
	}
};

function viewAktuelleAuktion(los_nr){
	try{
		var markup = '<p>' + charge_data[los_nr]['beschreibung'] + '</p>' +
			'<p>aktueller Preis: ' + charge_data[los_nr]['vkPreis'] + '</p>';
	
		$('#aktuelleAuktion').html(markup);
	}
	catch(e){
		$('#aktuelleAuktion').html('<p>aktuell keine Auktionen eingestellt</p>');		
	}
};

function viewCanvasData(los_nr){
	try{
		renderCanvas((charge_data[los_nr]['auktionDauer'] - charge_data[los_nr]['auktionLaufzeit']),(((charge_data[los_nr]['auktionDauer'] - charge_data[los_nr]['auktionLaufzeit']) / charge_data[los_nr]['auktionDauer']) * 360));
	}
	catch(e){
		$('#canvas').html('<p>aktuell keine Auktionen eingestellt</p>');			
	}	
}
function viewAuktionen(){
	$.get('templates/html/auktionsansicht.html', function(markup){
		$('#content').html(markup);	
	})
	
	var los_nr = document.getElementById('los_nr').value;
	los(los_nr);
};